aboutsummaryrefslogtreecommitdiff
path: root/sys/dev/pccbb
diff options
context:
space:
mode:
authorJulian Elischer <julian@FreeBSD.org>2007-10-20 23:23:23 +0000
committerJulian Elischer <julian@FreeBSD.org>2007-10-20 23:23:23 +0000
commit3745c395ecae17ef47be82433463d561629220b0 (patch)
tree705ce8283c36af96cf048c799a9c02ee91af62db /sys/dev/pccbb
parent2b3e7485f683cae86e5b9c773bbaabf920746f0e (diff)
Notes
Diffstat (limited to 'sys/dev/pccbb')
-rw-r--r--sys/dev/pccbb/pccbb.c6
-rw-r--r--sys/dev/pccbb/pccbb_pci.c2
2 files changed, 4 insertions, 4 deletions
diff --git a/sys/dev/pccbb/pccbb_pci.c b/sys/dev/pccbb/pccbb_pci.c
index 73a52b0d82cd..149bfacf1795 100644
--- a/sys/dev/pccbb/pccbb_pci.c
+++ b/sys/dev/pccbb/pccbb_pci.c
@@ -434,7 +434,7 @@ cbb_pci_attach(device_t brdev)
cbb_print_config(brdev);
/* Start the thread */
- if (kthread_create(cbb_event_thread, sc, &sc->event_thread, 0, 0,
+ if (kproc_create(cbb_event_thread, sc, &sc->event_thread, 0, 0,
"%s event thread", device_get_nameunit(brdev))) {
device_printf(brdev, "unable to create event thread.\n");
panic("cbb_create_event_thread");
diff --git a/sys/dev/pccbb/pccbb.c b/sys/dev/pccbb/pccbb.c
index 7b8fb62f4174..1af74a0a6c80 100644
--- a/sys/dev/pccbb/pccbb.c
+++ b/sys/dev/pccbb/pccbb.c
@@ -332,11 +332,11 @@ cbb_detach(device_t brdev)
cbb_set(sc, CBB_SOCKET_EVENT, 0xffffffff);
/*
* Wait for the thread to die. kthread_exit will do a wakeup
* on the event thread's struct thread * so that we know it is
* safe to proceed. IF the thread is running, set the please
* die flag and wait for it to comply. Since the wakeup on
* the event thread happens only in kthread_exit, we don't
* need to loop here.
*/
bus_teardown_intr(brdev, sc->irq_res, sc->intrhand);
@@ -529,7 +529,7 @@ cbb_event_thread(void *arg)
DEVPRINTF((sc->dev, "Thread terminating\n"));
sc->flags &= ~CBB_KTHREAD_RUNNING;
mtx_unlock(&sc->mtx);
- kthread_exit(0);
+ kproc_exit(0);
}
/************************************************************************/
@@ -332,11 +332,11 @@ cbb_detach(device_t brdev)
cbb_set(sc, CBB_SOCKET_EVENT, 0xffffffff);
/*
- * Wait for the thread to die. kthread_exit will do a wakeup
+ * Wait for the thread to die. kproc_exit will do a wakeup
* on the event thread's struct thread * so that we know it is
* safe to proceed. IF the thread is running, set the please
@@ -332,11 +332,11 @@ cbb_detach(device_t brdev)
* safe to proceed. IF the thread is running, set the please
* die flag and wait for it to comply. Since the wakeup on
- * the event thread happens only in kthread_exit, we don't
+ * the event thread happens only in kproc_exit, we don't
* need to loop here.
*/